<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\User;
use App\Models\pasiens;
use App\Models\jadwals;
use App\Models\pesans;
use App\Models\datakirims;
use App\Models\historis;
use Twilio\Rest\Client;
use Auth;

class DatakirimsController extends Controller
{
    //
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        $data = datakirims::where('del',0)->get();
        foreach ($data as $key => $value) {
            $pasien = array();
            $jadwal = array();
            $value->kode_pasien = unserialize($value->kode_pasien);
            foreach ($value->kode_pasien as $kay => $d) {
                $pasien[] = pasiens::find($d);
            }
            $value->pasien = $pasien;
            if($value->jenis == 0){
                $value->kode_jadwal = unserialize($value->kode_jadwal);
                foreach ($value->kode_jadwal as $kay => $d) {
                    $jadwal[] = jadwals::find($d);
                }
                $value->jadwal = $jadwal;
            }
        }

        $pesan = pesans::where('del',0)->get();
        $jadwal = jadwals::where('del',0)->get();
        $pasien = pasiens::where('del',0)->get();
        return view('datakirims/index', compact('data','pesan','jadwal','pasien'));
    }

    public function store(Request $request)
    {
        $forms = $request->all();
        $validator = Validator::make($request->all(), [
            'kode_kirim' => ['required'],
            'kode_pasien' => ['required'],
            'jenis' => ['required'],
            'kode_pesan' => ['required'],
        ]);
        if ($validator->fails()) {
            return back()->with(['error'=>'Data Tidak Lengkap.']);
        }else{
            $cek = datakirims::where('del',0)->where('kode_kirim',$forms['kode_kirim'])->first();
            if (isset($cek)) {
                return back()->with(['warning'=>'Kode Jadwal Sudah Dipakai.']);
            }else{
                $forms['kode_pasien'] = serialize($forms['kode_pasien']);
                if($forms['jenis'] == 0){
                    $forms['kode_jadwal'] = serialize($forms['kode_jadwal']);
                }
                $forms['kode_user'] = Auth::User()->id;
                datakirims::create($forms);
                return back()->with(['success'=>'Data Berhasil Disimpan.']);
            }
        }
    }

    public function update(Request $request)
    {
        $forms = $request->all();
        $cek = datakirims::find($forms['id']);
        if(isset($cek)){
            $cek2 = datakirims::where('del',0)->where('kode_kirim',$forms['kode_kirim'])->first();
            if(isset($cek2)){
                if($cek->id != $cek2->id){
                    return back()->with(['warning'=>'Kode Jadwal Sudah Dipakai.']);
                }
            }
            $cek->update($forms);
            return back()->with(['success'=>'Data berhasil diupdate.']);
        }else{
            return back()->with(['error'=>'Data Tidak Ada.']);
        }
    }

    public function hapus(Request $request)
    {
        $forms = $request->all();
        $cek = datakirims::find($forms['id']);
        if(isset($cek)){
            $cek->update(['del'=>1]);
            return back()->with(['warning'=>'Data berhasil dihapus.']);
        }else{
            return back()->with(['error'=>'Data Tidak Ada.']);
        }
    }

    public function kirimwa($id,$jenis)
    {
        $cek = datakirims::find($id);
        $pesan = $cek->get_pesan->pesan;
        $recipient = $cek->get_pasien->telepon;
        $sid    = getenv("TWILIO_AUTH_SID");
        $token  = getenv("TWILIO_AUTH_TOKEN");
        $wa_from= getenv("TWILIO_WHATSAPP_FROM");
        $twilio = new Client($sid, $token);

        if ($jenis == 1) {
            $pesan = str_replace("{{nama}}",$cek->get_pasien->nama,$pesan);
            $hari = date('w',strtotime($cek->tanggal));
            if ($hari == 0) {
                $hari = 'Minggu';
            }elseif ($hari == 1) {
                $hari = 'Senin';
            }elseif ($hari == 2) {
                $hari = 'Selasa';
            }elseif ($hari == 3) {
                $hari = 'Rabu';
            }elseif ($hari == 4) {
                $hari = 'Kamis';
            }elseif ($hari == 5) {
                $hari = 'Jumat';
            }elseif ($hari == 6) {
                $hari = 'Sabtu';
            }
            $pesan = str_replace("{{hari}}",$hari,$pesan);
            $pesan = str_replace("{{tanggal}}",date('d M Y',strtotime($cek->tanggal)),$pesan);
            $pesan = str_replace("{{jam}}",date('H:i',strtotime($cek->waktu)),$pesan);
        }else{
            $pesan = str_replace("{{nama}}",$cek->get_pasien->nama,$pesan);
            $hari = date('w',strtotime(date('Y-m-d')));
            if ($hari == 0) {
                $hari = 'Minggu';
            }elseif ($hari == 1) {
                $hari = 'Senin';
            }elseif ($hari == 2) {
                $hari = 'Selasa';
            }elseif ($hari == 3) {
                $hari = 'Rabu';
            }elseif ($hari == 4) {
                $hari = 'Kamis';
            }elseif ($hari == 5) {
                $hari = 'Jumat';
            }elseif ($hari == 6) {
                $hari = 'Sabtu';
            }
            $pesan = str_replace("{{hari}}",$hari,$pesan);
            $pesan = str_replace("{{tanggal}}",date('d M Y',strtotime(date('Y-m-d'))),$pesan);
            $pesan = str_replace("{{jam}}",date('H:i',strtotime($cek->get_jadwal->jam)),$pesan);
        }

        $body = $pesan;
        $kirim = $twilio->messages->create("whatsapp:$recipient",["from" => "whatsapp:$wa_from", "body" => $body]);
        historis::create([
            'kode_pasien' => $cek->kode_pasien,
            'kode_kirim' => $cek->id,
            'status' => 0,
            'waktu' => date('Y-m-d H:i:s'),
            'pesan' =>$body,
        ]);

        return 'Berhasil!';
    }

    public function kirimkan()
    {
        $tgl = date('Y-m-d');
        $jam = date('H:i:s');
        $day = date('w');
        $tgl = date('Y-m-d', strtotime('+1 days', strtotime($tgl)));
        // dd($tgl);
        $no = 0;
        $cek1 = datakirims::where('del',0)->where('jenis',1)->where('tanggal','<=',$tgl)->get();
        foreach ($cek1 as $key => $cek) {
            $kirim = $this->kirimwa($cek->id,1);
            datakirims::where('id',$cek->id)->update(['del'=>1]);
            $no++;
        }

        $cek2 = datakirims::where('del',0)->where('jenis',0)->get();
        // dd($cek2);
        $tgl = date('Y-m-d');
        foreach ($cek2 as $key => $cek) {
            if ($cek->get_jadwal->hari == 7) {
                if($jam >= $cek->get_jadwal->jam){
                    $cekh = historis::where('kode_kirim',$cek->id)->whereBetween('waktu',[$tgl.' 00:00:00',$tgl.' '.$jam])->count();
                    if($cekh == 0){
                        $kirim = $this->kirimwa($cek->id,0);
                        $no++;
                    }
                }
            }else{
                if($cek->get_jadwal->hari == $day){
                    if($jam >= $cek->get_jadwal->jam){
                        $cekh = historis::where('kode_kirim',$cek->id)->whereBetween('waktu',[$tgl.' 00:00:00',$tgl.' '.$jam])->count();
                        if($cekh == 0){
                            $kirim = $this->kirimwa($cek->id,0);
                            $no++;
                        }
                    }
                }
            }
        }

        $data = $no.' Pesan Telah Terkirim!';
        return $data;
    }
}
